# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.h2o.featurestore.api.v1 import CoreService_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2
from ai.h2o.featurestore.api.v1 import OnlineApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2
from ai.h2o.featurestore.api.v1 import RecommendationProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListJobs = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListJobs',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsResponse.FromString,
                )
        self.GetJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.Job.FromString,
                )
        self.GetJobProgress = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetJobProgress',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressInput.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressOutput.FromString,
                )
        self.StartExtractSchemaJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartExtractSchemaJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartExtractSchemaJobRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetExtractSchemaJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetExtractSchemaJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExtractSchemaResponse.FromString,
                )
        self.StartIngestJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartIngestJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartIngestJobRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetIngestJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetIngestJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestResponse.FromString,
                )
        self.StartRetrieveAsLinksJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveAsLinksJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetRetrieveAsLinksJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveAsLinksJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsLinksResponse.FromString,
                )
        self.RetrieveAsSpark = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RetrieveAsSpark',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsSparkResponse.FromString,
                )
        self.StartPreviewJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartPreviewJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PreviewRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetPreviewJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetPreviewJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PreviewResponse.FromString,
                )
        self.GetIngestWriteCredentials = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetIngestWriteCredentials',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialResponse.FromString,
                )
        self.StartRevertIngestJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartRevertIngestJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartRevertIngestJobRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetRevertIngestJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRevertIngestJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.HasPermissionToRetrieve = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/HasPermissionToRetrieve',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveResponse.FromString,
                )
        self.RegisterFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RegisterFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RegisterFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.CreateNewFeatureSetVersion = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateNewFeatureSetVersion',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateNewFeatureSetVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.GetOnlineRetrieveMeta = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetOnlineRetrieveMeta',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.OnlineRetrieveMeta.FromString,
                )
        self.GetVersion = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetVersion',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetVersionResponse.FromString,
                )
        self.GetFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.GetFeatureSetsLastMinorForCurrentMajor = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetsLastMinorForCurrentMajor',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetsLastMinorForCurrentMajorRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.ListFeatureSetVersions = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetVersions',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsVersionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetVersionsResponse.FromString,
                )
        self.DeleteFeatureSet = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSet',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListFeatureSets = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSets',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsResponse.FromString,
                )
        self.ListFeatureSetsAcrossProjects = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsAcrossProjects',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsAcrossProjectsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsResponse.FromString,
                )
        self.FeatureSetExists = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetExists',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetExistsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
                )
        self.GetIngestHistory = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetIngestHistory',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryResponse.FromString,
                )
        self.UpdateFeatureSetPrimaryKey = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetPrimaryKey',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetSecondaryKey = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetSecondaryKey',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetTags = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetTags',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringArrayFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetDataSourceDomains = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetDataSourceDomains',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringArrayFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetDescription = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetDescription',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetType = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetType',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTypeUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetOwner = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOwner',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetUserFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetApplicationName = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetApplicationName',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetApplicationId = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetApplicationId',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetDeprecated = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetDeprecated',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetProcessInterval = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetProcessInterval',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetProcessIntervalUnit = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetProcessIntervalUnit',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetProcessIntervalUnitUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetFlow = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetFlow',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetState = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetState',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetSecret = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetSecret',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetCustomData = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetCustomData',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetCustomDataUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateTimeToLiveOfflineInterval = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOfflineInterval',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateTimeToLiveOfflineIntervalUnit = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOfflineIntervalUnit',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateTimeToLiveOnlineInterval = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOnlineInterval',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateTimeToLiveOnlineIntervalUnit = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOnlineIntervalUnit',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetOnlineNamespace = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOnlineNamespace',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetOnlineTopic = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOnlineTopic',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetOnlineConnectionType = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOnlineConnectionType',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetLegalApproved = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetLegalApproved',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSetLegalApprovedNotes = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetLegalApprovedNotes',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureStatus = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureStatus',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureType = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureType',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureTypeUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureImportance = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureImportance',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureDoubleFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureDescription = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureDescription',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureSpecial = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSpecial',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureAnomalyDetection = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureAnomalyDetection',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureBooleanFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFeatureClassifier = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureClassifier',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.IsFeatureSetSchemaCompatible = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/IsFeatureSetSchemaCompatible',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityResponse.FromString,
                )
        self.FeatureSetSchemaPatch = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetSchemaPatch',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchResponse.FromString,
                )
        self.ListProjects = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListProjects',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsResponse.FromString,
                )
        self.CreateProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectResponse.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
                )
        self.DeleteProject = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/DeleteProject',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetProjectsDefault = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetProjectsDefault',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectsDefaultResponse.FromString,
                )
        self.ProjectExists = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ProjectExists',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectExistsRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
                )
        self.UpdateProjectSecret = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectSecret',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectBooleanFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateProjectLocked = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectLocked',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectBooleanFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateProjectOwner = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectOwner',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectUserFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateProjectDescription = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectDescription',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectStringFieldUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateProjectCustomData = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectCustomData',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectCustomDataUpdateRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetAccessToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetAccessToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RefreshTokenRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.AccessTokenResponse.FromString,
                )
        self.GetUserByMail = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetUserByMail',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailResponse.FromString,
                )
        self.Logout = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/Logout',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LogoutRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetActiveUser = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetActiveUser',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActiveUserResponse.FromString,
                )
        self.Login = channel.unary_stream(
                '/ai.h2o.featurestore.api.v1.CoreService/Login',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LoginResponse.FromString,
                )
        self.AddFeatureSetPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/AddFeatureSetPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.AddProjectPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/AddProjectPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
                )
        self.RemoveFeatureSetPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RemoveFeatureSetPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
                )
        self.RemoveProjectPermission = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RemoveProjectPermission',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
                )
        self.RevokeToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/RevokeToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GenerateToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GenerateToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTokenRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RawTokenResponse.FromString,
                )
        self.ListTokens = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListTokens',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTokensResponse.FromString,
                )
        self.GetToken = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetToken',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenResponse.FromString,
                )
        self.OnlineRetrieve = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/OnlineRetrieve',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.FromString,
                )
        self.OnlineIngest = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/OnlineIngest',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineIngestRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StartMaterializationOnlineJob = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/StartMaterializationOnlineJob',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartMaterializationOnlineRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                )
        self.GetMaterializationOnlineJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetMaterializationOnlineJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MaterializationOnlineResponse.FromString,
                )
        self.GetComputeStatisticsJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetComputeStatisticsJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetComputeRecommendationClassifiersJobOutput = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetComputeRecommendationClassifiersJobOutput',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GenerateTransformationUpload = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GenerateTransformationUpload',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadResponse.FromString,
                )
        self.ListRecommendationClassifiers = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/ListRecommendationClassifiers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.ListRecommendationClassifierResponse.FromString,
                )
        self.CreateRecommendationClassifier = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/CreateRecommendationClassifier',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.CreateRecommendationClassifierRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRecommendations = channel.unary_unary(
                '/ai.h2o.featurestore.api.v1.CoreService/GetRecommendations',
                request_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationRequest.SerializeToString,
                response_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationResponse.FromString,
                )


class CoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListJobs(self, request, context):
        """Jobs API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJobProgress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartExtractSchemaJob(self, request, context):
        """Extract Schema API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtractSchemaJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartIngestJob(self, request, context):
        """Feature Set API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIngestJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRetrieveAsLinksJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRetrieveAsLinksJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveAsSpark(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartPreviewJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPreviewJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIngestWriteCredentials(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRevertIngestJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRevertIngestJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HasPermissionToRetrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNewFeatureSetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnlineRetrieveMeta(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetsLastMinorForCurrentMajor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSetsAcrossProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureSetExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIngestHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetPrimaryKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetSecondaryKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetDataSourceDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetDescription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetOwner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetApplicationName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetApplicationId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetDeprecated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetProcessInterval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetProcessIntervalUnit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetFlow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetCustomData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTimeToLiveOfflineInterval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTimeToLiveOfflineIntervalUnit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTimeToLiveOnlineInterval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTimeToLiveOnlineIntervalUnit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetOnlineNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetOnlineTopic(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetOnlineConnectionType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetLegalApproved(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSetLegalApprovedNotes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureImportance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureDescription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureSpecial(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureAnomalyDetection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureClassifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsFeatureSetSchemaCompatible(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureSetSchemaPatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjects(self, request, context):
        """Project API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectsDefault(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProjectExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectLocked(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectOwner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectDescription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProjectCustomData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccessToken(self, request, context):
        """Auth API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserByMail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddFeatureSetPermission(self, request, context):
        """Permissions API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProjectPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveFeatureSetPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveProjectPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeToken(self, request, context):
        """PAT API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnlineRetrieve(self, request, context):
        """Online API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnlineIngest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartMaterializationOnlineJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMaterializationOnlineJobOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComputeStatisticsJobOutput(self, request, context):
        """ComputeStatistics API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComputeRecommendationClassifiersJobOutput(self, request, context):
        """ComputeRecommendationClassifier API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateTransformationUpload(self, request, context):
        """Upload API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRecommendationClassifiers(self, request, context):
        """Recommendation API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecommendationClassifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecommendations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListJobs,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsResponse.SerializeToString,
            ),
            'GetJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.Job.SerializeToString,
            ),
            'GetJobProgress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJobProgress,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressInput.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressOutput.SerializeToString,
            ),
            'StartExtractSchemaJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartExtractSchemaJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartExtractSchemaJobRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetExtractSchemaJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtractSchemaJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExtractSchemaResponse.SerializeToString,
            ),
            'StartIngestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartIngestJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartIngestJobRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetIngestJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIngestJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestResponse.SerializeToString,
            ),
            'StartRetrieveAsLinksJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRetrieveAsLinksJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetRetrieveAsLinksJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRetrieveAsLinksJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsLinksResponse.SerializeToString,
            ),
            'RetrieveAsSpark': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveAsSpark,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsSparkResponse.SerializeToString,
            ),
            'StartPreviewJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartPreviewJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PreviewRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetPreviewJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPreviewJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PreviewResponse.SerializeToString,
            ),
            'GetIngestWriteCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIngestWriteCredentials,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialResponse.SerializeToString,
            ),
            'StartRevertIngestJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRevertIngestJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartRevertIngestJobRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetRevertIngestJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRevertIngestJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'HasPermissionToRetrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.HasPermissionToRetrieve,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveResponse.SerializeToString,
            ),
            'RegisterFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RegisterFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'CreateNewFeatureSetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNewFeatureSetVersion,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateNewFeatureSetVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'GetOnlineRetrieveMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnlineRetrieveMeta,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.OnlineRetrieveMeta.SerializeToString,
            ),
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetVersionResponse.SerializeToString,
            ),
            'GetFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'GetFeatureSetsLastMinorForCurrentMajor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetsLastMinorForCurrentMajor,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetsLastMinorForCurrentMajorRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'ListFeatureSetVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetVersions,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsVersionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetVersionsResponse.SerializeToString,
            ),
            'DeleteFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSet,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSets,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsResponse.SerializeToString,
            ),
            'ListFeatureSetsAcrossProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSetsAcrossProjects,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsAcrossProjectsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsResponse.SerializeToString,
            ),
            'FeatureSetExists': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureSetExists,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetExistsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.SerializeToString,
            ),
            'GetIngestHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIngestHistory,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryResponse.SerializeToString,
            ),
            'UpdateFeatureSetPrimaryKey': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetPrimaryKey,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetSecondaryKey': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetSecondaryKey,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetTags': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetTags,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringArrayFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetDataSourceDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetDataSourceDomains,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringArrayFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetDescription': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetDescription,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetType': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetType,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTypeUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetOwner,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetUserFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetApplicationName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetApplicationName,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetApplicationId': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetApplicationId,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetDeprecated': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetDeprecated,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetProcessInterval': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetProcessInterval,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetProcessIntervalUnit': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetProcessIntervalUnit,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetProcessIntervalUnitUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetFlow': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetFlow,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetState,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetSecret,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetCustomData': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetCustomData,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetCustomDataUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateTimeToLiveOfflineInterval': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTimeToLiveOfflineInterval,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateTimeToLiveOfflineIntervalUnit': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTimeToLiveOfflineIntervalUnit,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateTimeToLiveOnlineInterval': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTimeToLiveOnlineInterval,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateTimeToLiveOnlineIntervalUnit': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTimeToLiveOnlineIntervalUnit,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetOnlineNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetOnlineNamespace,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetOnlineTopic': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetOnlineTopic,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetOnlineConnectionType': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetOnlineConnectionType,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetLegalApproved': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetLegalApproved,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSetLegalApprovedNotes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSetLegalApprovedNotes,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureStatus,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureType': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureType,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureTypeUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureImportance': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureImportance,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureDoubleFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureDescription': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureDescription,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureSpecial': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureSpecial,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureAnomalyDetection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureAnomalyDetection,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureBooleanFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFeatureClassifier': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureClassifier,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'IsFeatureSetSchemaCompatible': grpc.unary_unary_rpc_method_handler(
                    servicer.IsFeatureSetSchemaCompatible,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityResponse.SerializeToString,
            ),
            'FeatureSetSchemaPatch': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureSetSchemaPatch,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchResponse.SerializeToString,
            ),
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsResponse.SerializeToString,
            ),
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectResponse.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetProjectRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.SerializeToString,
            ),
            'DeleteProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProject,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteProjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetProjectsDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectsDefault,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectsDefaultResponse.SerializeToString,
            ),
            'ProjectExists': grpc.unary_unary_rpc_method_handler(
                    servicer.ProjectExists,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectExistsRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.SerializeToString,
            ),
            'UpdateProjectSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectSecret,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectBooleanFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateProjectLocked': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectLocked,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectBooleanFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateProjectOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectOwner,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectUserFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateProjectDescription': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectDescription,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectStringFieldUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateProjectCustomData': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProjectCustomData,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectCustomDataUpdateRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccessToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RefreshTokenRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.AccessTokenResponse.SerializeToString,
            ),
            'GetUserByMail': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserByMail,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LogoutRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetActiveUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveUser,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActiveUserResponse.SerializeToString,
            ),
            'Login': grpc.unary_stream_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LoginResponse.SerializeToString,
            ),
            'AddFeatureSetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.AddFeatureSetPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'AddProjectPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.AddProjectPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.SerializeToString,
            ),
            'RemoveFeatureSetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveFeatureSetPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.SerializeToString,
            ),
            'RemoveProjectPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveProjectPermission,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.SerializeToString,
            ),
            'RevokeToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GenerateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTokenRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RawTokenResponse.SerializeToString,
            ),
            'ListTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTokens,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTokensResponse.SerializeToString,
            ),
            'GetToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToken,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenResponse.SerializeToString,
            ),
            'OnlineRetrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.OnlineRetrieve,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.SerializeToString,
            ),
            'OnlineIngest': grpc.unary_unary_rpc_method_handler(
                    servicer.OnlineIngest,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineIngestRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StartMaterializationOnlineJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartMaterializationOnlineJob,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartMaterializationOnlineRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ),
            'GetMaterializationOnlineJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMaterializationOnlineJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MaterializationOnlineResponse.SerializeToString,
            ),
            'GetComputeStatisticsJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComputeStatisticsJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetComputeRecommendationClassifiersJobOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComputeRecommendationClassifiersJobOutput,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GenerateTransformationUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateTransformationUpload,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadResponse.SerializeToString,
            ),
            'ListRecommendationClassifiers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRecommendationClassifiers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.ListRecommendationClassifierResponse.SerializeToString,
            ),
            'CreateRecommendationClassifier': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecommendationClassifier,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.CreateRecommendationClassifierRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRecommendations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecommendations,
                    request_deserializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationRequest.FromString,
                    response_serializer=ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.h2o.featurestore.api.v1.CoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListJobs',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.Job.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJobProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetJobProgress',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressInput.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobProgressOutput.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartExtractSchemaJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartExtractSchemaJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartExtractSchemaJobRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtractSchemaJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetExtractSchemaJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExtractSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartIngestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartIngestJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartIngestJobRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIngestJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetIngestJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRetrieveAsLinksJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartRetrieveAsLinksJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRetrieveAsLinksJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRetrieveAsLinksJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveAsSpark(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RetrieveAsSpark',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RetrieveAsSparkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartPreviewJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartPreviewJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PreviewRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPreviewJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetPreviewJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.PreviewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIngestWriteCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetIngestWriteCredentials',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.IngestWriteCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRevertIngestJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartRevertIngestJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartRevertIngestJobRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRevertIngestJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRevertIngestJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HasPermissionToRetrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/HasPermissionToRetrieve',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.HasPermissionToRetrieveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RegisterFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RegisterFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNewFeatureSetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateNewFeatureSetVersion',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateNewFeatureSetVersionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnlineRetrieveMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetOnlineRetrieveMeta',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.OnlineRetrieveMeta.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetVersion',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetsLastMinorForCurrentMajor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetFeatureSetsLastMinorForCurrentMajor',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetFeatureSetsLastMinorForCurrentMajorRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetVersions',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsVersionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteFeatureSet',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSets',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSetsAcrossProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListFeatureSetsAcrossProjects',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsAcrossProjectsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureSetExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetExists',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetExistsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIngestHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetIngestHistory',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetIngestHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetPrimaryKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetPrimaryKey',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetSecondaryKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetSecondaryKey',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetTags',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringArrayFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetDataSourceDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetDataSourceDomains',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringArrayFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetDescription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetDescription',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetType',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTypeUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOwner',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetUserFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetApplicationName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetApplicationName',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetApplicationId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetApplicationId',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetDeprecated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetDeprecated',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetProcessInterval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetProcessInterval',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetProcessIntervalUnit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetProcessIntervalUnit',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetProcessIntervalUnitUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetFlow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetFlow',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetState',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetSecret',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetCustomData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetCustomData',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetCustomDataUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTimeToLiveOfflineInterval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOfflineInterval',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTimeToLiveOfflineIntervalUnit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOfflineIntervalUnit',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTimeToLiveOfflineIntervalUnitUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTimeToLiveOnlineInterval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOnlineInterval',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetIntFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTimeToLiveOnlineIntervalUnit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateTimeToLiveOnlineIntervalUnit',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetTimeToLiveOnlineIntervalUnitUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetOnlineNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOnlineNamespace',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetOnlineTopic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOnlineTopic',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetOnlineConnectionType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetOnlineConnectionType',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetLegalApproved(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetLegalApproved',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetBooleanFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSetLegalApprovedNotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSetLegalApprovedNotes',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureStatus',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureType',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureTypeUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureImportance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureImportance',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureDoubleFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureDescription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureDescription',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureSpecial(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureSpecial',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureAnomalyDetection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureAnomalyDetection',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureBooleanFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureClassifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateFeatureClassifier',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsFeatureSetSchemaCompatible(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/IsFeatureSetSchemaCompatible',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaCompatibilityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureSetSchemaPatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/FeatureSetSchemaPatch',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetSchemaPatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListProjects',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.CreateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetProjectRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/DeleteProject',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.DeleteProjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectsDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetProjectsDefault',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectsDefaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProjectExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ProjectExists',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectExistsRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectSecret',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectBooleanFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectLocked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectLocked',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectBooleanFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectOwner',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectUserFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectDescription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectDescription',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectStringFieldUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProjectCustomData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/UpdateProjectCustomData',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectCustomDataUpdateRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetAccessToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RefreshTokenRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.AccessTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserByMail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetUserByMail',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetUserByMailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/Logout',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LogoutRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActiveUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetActiveUser',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetActiveUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ai.h2o.featurestore.api.v1.CoreService/Login',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddFeatureSetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/AddFeatureSetPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddProjectPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/AddProjectPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveFeatureSetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RemoveFeatureSetPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetPermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.FeatureSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveProjectPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RemoveProjectPermission',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectPermissionRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/RevokeToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GenerateToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTokenRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.RawTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListTokens',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.ListTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetToken',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.TokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnlineRetrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/OnlineRetrieve',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineRetrieveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnlineIngest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/OnlineIngest',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2.OnlineIngestRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartMaterializationOnlineJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/StartMaterializationOnlineJob',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.StartMaterializationOnlineRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMaterializationOnlineJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetMaterializationOnlineJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.MaterializationOnlineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComputeStatisticsJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetComputeStatisticsJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComputeRecommendationClassifiersJobOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetComputeRecommendationClassifiersJobOutput',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.JobId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateTransformationUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GenerateTransformationUpload',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GenerateTransformationUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRecommendationClassifiers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/ListRecommendationClassifiers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.ListRecommendationClassifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecommendationClassifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/CreateRecommendationClassifier',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2.CreateRecommendationClassifierRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecommendations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ai.h2o.featurestore.api.v1.CoreService/GetRecommendations',
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationRequest.SerializeToString,
            ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_CoreService__pb2.GetRecommendationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
